/**
 * Copyright (C) 2010 Hamburg Sud
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hamburgsud.aludratest;


import com.hamburgsud.aludratest.action.condition.Condition;
import com.hamburgsud.aludratest.action.condition.selenium.SeleniumCondition;
import com.hamburgsud.aludratest.action.interaction.Interaction;
import com.hamburgsud.aludratest.action.interaction.selenium.SeleniumInteraction;
import com.hamburgsud.aludratest.action.verification.Verification;
import com.hamburgsud.aludratest.action.verification.selenium.SeleniumVerification;
import com.hamburgsud.aludratest.wrapper.Wrapper;
import com.hamburgsud.aludratest.wrapper.selenium.SeleniumWrapper;
import com.hamburgsud.log4testing.core.data.TestCase;
import com.hamburgsud.log4testing.core.data.TestStepGroup;

public class DefaultAludraTest implements AludraTest {

	private Interaction interaction;
	private Verification verification;
	private Condition condition;
	private TestCase testCase;
	
	private DefaultAludraTest() {
	}

	public DefaultAludraTest(final TestCase testCase) {
		this();
		init(testCase);
	}
	
	private void init(final TestCase testCase) {
		this.testCase = testCase;
		final Wrapper wrapper = new SeleniumWrapper();
		interaction = new SeleniumInteraction(wrapper, testCase);
		verification = new SeleniumVerification(wrapper, testCase);
		condition = new SeleniumCondition(wrapper, testCase);
	}

	public Interaction perform() {
		return interaction;
	}

	public Verification verify() {
		return verification;
	}

	public TestStepGroup newTestStepGroup(final String name) {
		return testCase.newTestStepGroup(name);
	}

	public Condition check() {
		return condition;
	}

}
