/**
 * Copyright (C) 2010 Hamburg Sud
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hamburgsud.aludratest.action.condition.selenium;

import static com.hamburgsud.aludratest.locator.LocatorProvider.getDefaultElementLocator;

import com.hamburgsud.aludratest.action.Action;
import com.hamburgsud.aludratest.action.condition.Condition;
import com.hamburgsud.aludratest.caller.Command;
import com.hamburgsud.aludratest.handler.DefaultVerificationExceptionHandler;
import com.hamburgsud.aludratest.locator.element.ElementLocator;
import com.hamburgsud.aludratest.wrapper.Wrapper;
import com.hamburgsud.log4testing.core.data.TestCase;

public class SeleniumCondition extends Action implements Condition {

	public SeleniumCondition(Wrapper wrapper, TestCase testCase) {
		super(wrapper, testCase);
		setExceptionHandler(new DefaultVerificationExceptionHandler());
	}
	
	public boolean isElementPresent(final Object locator) {
		final ElementLocator elementLocator = getDefaultElementLocator(wrapper,
				locator);
		return getConditionCommandCaller().callCondition(new Command() {

			@Override
			public void call() throws Exception {
				wrapper.waitForElement(elementLocator);
			}

			@Override
			public String getName() {
				return "check_isElementPresent";
			}

			@Override
			public String getMessage() {
				return getLocatorMessage(elementLocator);
			}
		});
	}
	
	public boolean isElementPresent(final Object locator, final long timeout) {
		final ElementLocator elementLocator = getDefaultElementLocator(wrapper,
				locator);
		return getConditionCommandCaller().callCondition(new Command() {

			@Override
			public void call() throws Exception {
				wrapper.waitForElement(elementLocator, timeout);
			}

			@Override
			public String getName() {
				return "check_isElementPresent";
			}

			@Override
			public String getMessage() {
				return getLocatorMessage(elementLocator);
			}
		});
	}
	
	/**
	 * To check, if a element does not exist within timeout
	 * 
	 * @param locator
	 *            of the element to highlight
     * @return
     *        true, if element does not exist
	 */
	public boolean isElementNotPresent(final Object locator) {
		final ElementLocator elementLocator = getDefaultElementLocator(wrapper,
				locator);
		return getConditionCommandCaller().callCondition(new Command() {

			@Override
			public void call() throws Exception {
				wrapper.waitForElementNotPresent(elementLocator);
			}

			@Override
			public String getName() {
				return "check_isElementNotPresent";
			}

			@Override
			public String getMessage() {
				return getLocatorMessage(elementLocator);
			}

		});
	}
	
	/**
	 * To check, if a element does not exist within timeout
	 * 
	 * @param locator
	 *            of the element to highlight
	 * @param timeout
	 * 			  timeout to wait
     * @return
     *        true, if element does not exist
	 */
	public boolean isElementNotPresent(final Object locator, final long timeout) {
		final ElementLocator elementLocator = getDefaultElementLocator(wrapper,
				locator);
		return getConditionCommandCaller().callCondition(new Command() {

			@Override
			public void call() throws Exception {
				wrapper.waitForElementNotPresent(elementLocator, timeout);
			}

			@Override
			public String getName() {
				return "check_isElementNotPresent";
			}

			@Override
			public String getMessage() {
				return getLocatorMessage(elementLocator);
			}

		});
	}
	
	public boolean isElementVisible(final Object locator) {
		final ElementLocator elementLocator = getDefaultElementLocator(wrapper,
				locator);
		return getConditionCommandCaller().callCondition(new Command() {

			@Override
			public void call() throws Exception {
				wrapper.waitForVisible(elementLocator);
			}

			@Override
			public String getName() {
				return "check_isElementVisible";
			}

			@Override
			public String getMessage() {
				return getLocatorMessage(elementLocator);
			}

		});
	}
	
	public boolean isElementVisible(final Object locator, final long timeout) {
		final ElementLocator elementLocator = getDefaultElementLocator(wrapper,
				locator);
		return getConditionCommandCaller().callCondition(new Command() {

			@Override
			public void call() throws Exception {
				wrapper.waitForVisible(elementLocator, timeout);
			}

			@Override
			public String getName() {
				return "check_isElementVisible";
			}

			@Override
			public String getMessage() {
				return getLocatorMessage(elementLocator);
			}

		});
	}
	
	public boolean isElementEnabled(final Object locator) {
		final ElementLocator elementLocator = getDefaultElementLocator(wrapper,
				locator);
		return getConditionCommandCaller().callCondition(new Command() {

			@Override
			public void call() throws Exception {
				wrapper.waitForEnabled(elementLocator);
			}

			@Override
			public String getName() {
				return "check_isElementEnabled";
			}

			@Override
			public String getMessage() {
				return getLocatorMessage(elementLocator);
			}

		});
	}
	
	public boolean isElementEnabled(final Object locator, final long timeout) {
		final ElementLocator elementLocator = getDefaultElementLocator(wrapper,
				locator);
		return getConditionCommandCaller().callCondition(new Command() {

			@Override
			public void call() throws Exception {
				wrapper.waitForEnabled(elementLocator);
			}

			@Override
			public String getName() {
				return "check_isElementEnabled";
			}

			@Override
			public String getMessage() {
				return getLocatorMessage(elementLocator);
			}

		});
	}
	
}
