/**
 * Copyright (C) 2010 Hamburg Sud
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hamburgsud.aludratest.gui.component;


import com.hamburgsud.aludratest.AludraTest;
import com.hamburgsud.log4testing.core.data.TestStep;

public class Dropdownbox extends Element {

	public Dropdownbox(AludraTest aludraTest, Object locator) {
		super(aludraTest, locator);
	}

	/**
	 * Selects an entry of a DropDownBox by:
	 * <ul>	
	 * <li>its Label e.g. "APPROVED"</li>
	 * <li>its Index e.g. new IndexLocator("1")</li>
	 *  </ul>
	 * @param option is a String or IndexLocator which selects the needed entry
	 * @return
	 */
	public TestStep selectEntry(final Object option) {
		return perform().selectDropDownEntry(locator, option);
	}
	
	public String getSelectedEntry() {
		return perform().getInputFieldValue(locator);
	}

	public TestStep hasSelected(final String label) {
		return verify().dropDownEntrySelection(locator, label);
	}
	
	public TestStep hasValues(final String... values) {
		return verify().hasValues(locator, values);
	}
	
	/**
	 * Checks if a DropDownBox has the right labels
	 * The check fails if: 
	 * <ul>
	 * <li>order of the Labels is wrong</li>
	 * <li>not every Label is mentioned</li>
	 * <li>a wrong Label is mentioned</li>
	 * </ul>
	 * @param labels which should be checked
	 */
	public TestStep hasLabels(final String... labels) {
		return verify().hasLabels(locator, labels);
	}
	
	/**
	 * Checks if the mentioned labels are listed in a DropDownBox
	 * @param labels which should be checked
	 */
	public TestStep containsLabels(final String... labels){
		return verify().containsLabels(locator,labels);
	}
	
	/** 
	 * Determines whether the specified input element is editable, ie hasn't been disabled.
     * This method is only available for input element.
     * 
	 * @return true if the input element is editable, false otherwise
	*/
	public boolean enabled(){
		return check().isElementEnabled(locator);
	}
	
	/** 
	 * Determines whether the specified input element is editable, ie hasn't been disabled.
     * This method is only available for input element.
     * 
     * @param timeout
     * 		timeout to wait
	 * @return true if the input element is editable, false otherwise
	*/
	public boolean enabled(final long timeout){
		return check().isElementEnabled(locator, timeout);
	}

	/**
	 * To select or check option for the Dropdownbox
	 * 
	 * @param option
	 *            if text starts with '!' then select the option of the
	 *            Dropdownbox if text starts with '?' then check the option of
	 *            the Dropdownbox
	 * 
	 * @return a logging object which contains information about the success of
	 *         the execution of this action.
	 */
	public TestStep value(String option) {
		String data = option.substring(1);
		if (option.startsWith("!")) {
			return selectEntry(data);
		} else if (option.startsWith("?")) {
			return hasSelected(data);
		} else {
			return selectEntry(option);
		}
	}

}
