/**
 * Copyright (C) 2010 Hamburg Sud
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hamburgsud.aludratest.gui.component;


import com.hamburgsud.aludratest.AludraTest;
import com.hamburgsud.log4testing.core.data.TestStep;

public class InputField extends Element {
	
	final private static String ATTRIBUTE_MAXLENGTH = "maxLength";
	
	public InputField(final AludraTest aludraTest, final Object locator) {
		super(aludraTest, locator);
	}

	public TestStep enter(final String text) {
		return perform().type(locator, text);
	}
	
	public TestStep equals(final String text) {
		return verify().value(locator, text);
	}

	public TestStep equals(final Number num) {
		return verify().value(locator, num);
	}

	public String getText() {
		return perform().getInputFieldValue(locator);
	}
	
	public TestStep hasText(final String expectedText) {
		return verify().value(locator, expectedText);
	}
	
	public TestStep hasMaxLength(final int expectedMaxLength) {
		return verify().hasAttributeValue(locator, ATTRIBUTE_MAXLENGTH, String.valueOf(expectedMaxLength));
	}
	
	/** 
	 * Determines whether the specified input element is editable, ie hasn't been disabled.
     * This method is only available for input element.
     * 
	 * @return true if the input element is editable, false otherwise
	*/
	public boolean enabled(){
		return check().isElementEnabled(locator);
	}
	
	/** 
	 * Determines whether the specified input element is editable, ie hasn't been disabled.
     * This method is only available for input element.
     * 
     * @param timeout
     * 		timeout to wait
	 * @return true if the input element is editable, false otherwise
	*/
	public boolean enabled(final long timeout){
		return check().isElementEnabled(locator, timeout);
	}
	
	/**
	 * To enter or check a text of this InputField
	 * 
	 * @param text
	 *            if text starts with '!' enter this text; if text starts
	 *            with '?' check this text
	 *            if text is empty delete the text of the element
	 * 
	 * @return a logging object which contains information about the success of
	 *         the execution of this action.
	 */
	public TestStep value(String text) {
		String data = (text.length() > 0) ? text.substring(1) : text;
		if (text.startsWith("!")) {
			return enter(data);
		} else if (text.startsWith("?")) {
			return equals(data);
		} else {
			return enter(text);
		}
	}
	
}
