/**
 * Copyright (C) 2010 Hamburg Sud
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hamburgsud.aludratest.gui.component;


import com.hamburgsud.aludratest.AludraTest;
import com.hamburgsud.log4testing.core.data.TestStep;

public class RadioButton extends Element {

	public RadioButton(final AludraTest aludraTest, final Object locator) {
		super(aludraTest, locator);
	}

	public TestStep select() {
		return perform().selectRadiobutton(locator);
	}
	
	public TestStep isChecked() {
		return verify().isChecked(locator);
	}
	
	public TestStep isChecked(final boolean expected) {
		return verify().isChecked(expected, locator);
	}
	
	/** 
	 * Determines whether the specified input element is editable, ie hasn't been disabled.
     * This method is only available for input element.
     * 
	 * @return true if the input element is editable, false otherwise
	*/
	public boolean enabled(){
		return check().isElementEnabled(locator);
	}
	
	/** 
	 * Determines whether the specified input element is editable, ie hasn't been disabled.
     * This method is only available for input element.
     * 
     * @param timeout
     * 		timeout to wait
	 * @return true if the input element is editable, false otherwise
	*/
	public boolean enabled(final long timeout){
		return check().isElementEnabled(locator, timeout);
	}
	
	/**
	 * To select or check status for the Radiobutton
	 * 
	 * @param select
	 *            if text starts with '!true' then select the Radiobutton if
	 *            text starts with '?' then check the status of the Radiobutton
	 * 
	 * @return a logging object which contains information about the success of
	 *         the execution of this action.
	 */
	public TestStep value(String select) {
		if (select.startsWith("?")) {
			String data = select.substring(1);
			return isChecked(Boolean.parseBoolean(data));
		} else {
			return select();
		}
	}

}
