/**
 * Copyright (C) 2010 Hamburg Sud
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hamburgsud.aludratest.handler;


import com.hamburgsud.aludratest.caller.Command;
import com.hamburgsud.aludratest.wrapper.Wrapper;
import com.hamburgsud.log4testing.core.data.TestStep;

public interface ExceptionHandler {

	/**
	 * Handles the passed through exception. What the exception handler does
	 * with this exception depends on the implementing class.<br/>
	 * Normally the exception handler shall gain all available information
	 * provided by the passed through parameters and about the application under
	 * test. These information shall be stored in <code>testStep</code> to help
	 * a test case writer by identifying the bug, to report and to fix it.<br/>
	 * 
	 * @param e
	 *            is the exception to handle
	 * @param testStep
	 *            is an object to log what occurred while execution of the
	 *            corresponding test step. The handler should store all
	 *            available information about the handled exception and the
	 *            current state of the application under test in this object.
	 * @param calledCommand
	 *            is the command on which execution the exception has occurred
	 * @param wrapper
	 *            to give the handler direct access to the application under
	 *            test. With this instance the handler has the ability to gain
	 *            more information which can be stored in <code>testStep</code>.
	 * @return <code>false</code> when the underlying exception handler thinks
	 *         that the execution of the following test steps of this test case
	 *         should not be continued; <code>true</code> when the exception
	 *         handler thinks that the execution can be continued. This return
	 *         value is just a recommendation by the underlying exception
	 *         handler.
	 */
	boolean handle(Exception e, TestStep testStep, Command calledCommand,
			Wrapper wrapper);

}
