/**
 * Copyright (C) 2010 Hamburg Sud
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hamburgsud.aludratest.junit;

import java.util.LinkedList;
import java.util.Queue;
import java.util.concurrent.CompletionService;
import java.util.concurrent.ExecutorCompletionService;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.Future;

import org.junit.internal.builders.AllDefaultPossibilitiesBuilder;
import org.junit.runner.Runner;
import org.junit.runners.Suite;
import org.junit.runners.model.InitializationError;
import org.junit.runners.model.RunnerScheduler;

import com.hamburgsud.aludratest.configuration.SeleniumWrapperConfiguration;
import com.hamburgsud.log4testing.core.TestLogger;
import com.hamburgsud.log4testing.core.data.TestCase;
import com.hamburgsud.log4testing.core.data.TestSuite;
import com.hamburgsud.log4testing.core.output.TestLogWriter;

public final class AludraTestTestSuiteRunner extends Suite {

	public AludraTestTestSuiteRunner(final Class<?> klass)
			throws InitializationError {
		super(klass, new AllDefaultPossibilitiesBuilder(true) {
			
			@Override
			public Runner runnerForClass(Class<?> testClass) throws Throwable {
				final Object defaultTestRunner = super.runnerForClass(testClass);
				addTestCaseToTestSuite(testClass);
				return (Runner) defaultTestRunner;
			}

			private void addTestCaseToTestSuite(Class<?> testClass) {
				if (AludraTestTestCase.class.isAssignableFrom(testClass)) {
					final TestCase testCase = TestLogger.getTestCase(testClass);
					final TestSuite testSuite = TestLogger.getTestSuite(klass);
					testSuite.addTestCase(testCase);
				}
			}

		});
		setScheduler(new RunnerScheduler() {

			ExecutorService executorService = Executors.newFixedThreadPool(
					SeleniumWrapperConfiguration.SELENIUM_HOSTS.size(),
					new PoolThreadFactory(klass.getSimpleName()));
			
			CompletionService<Void> completionService = new ExecutorCompletionService<Void>(
					executorService);
			
			Queue<Future<Void>> tasks = new LinkedList<Future<Void>>();

			public void schedule(final Runnable childStatement) {
				Future<Void> future = completionService.submit(childStatement,
						null);
				tasks.offer(future);
			}

			public void finished() {
				try {
					while (!tasks.isEmpty())
						tasks.remove(completionService.take());
				} catch (InterruptedException e) {
					Thread.currentThread().interrupt();
				} finally {
					while (!tasks.isEmpty())
						tasks.poll().cancel(true);
					executorService.shutdownNow();
					final TestSuite testSuite = TestLogger.getTestSuite(klass);
					TestLogWriter.write(testSuite);
				}
			}

		});
	}

}
