/**
 * Copyright (C) 2010 Hamburg Sud
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hamburgsud.aludratest.wrapper;

import com.hamburgsud.aludratest.exception.AludraTestException;
import com.hamburgsud.aludratest.exception.functional.ElementCouldBeFoundException;
import com.hamburgsud.aludratest.exception.functional.ElementCouldNotBeFoundException;
import com.hamburgsud.aludratest.exception.functional.verification.NotEditableException;
import com.hamburgsud.aludratest.exception.functional.verification.NotInForegroundException;
import com.hamburgsud.aludratest.exception.functional.verification.NotVisibleException;
import com.hamburgsud.aludratest.exception.technical.LocatorNotSupportedException;
import com.hamburgsud.aludratest.exception.technical.TechnicalException;
import com.hamburgsud.aludratest.locator.element.ElementLocator;
import com.hamburgsud.aludratest.locator.option.OptionLocator;
import com.hamburgsud.aludratest.locator.window.WindowLocator;
import com.hamburgsud.aludratest.wrapper.selenium.Condition;
import com.hamburgsud.log4testing.core.data.attachment.Attachment;

public interface Wrapper {

	public void tearDown() throws AludraTestException;

	public void open(String url) throws AludraTestException;

	public void refresh() throws AludraTestException;

	public void click(final ElementLocator locator) throws AludraTestException;

	public boolean isElementPresent(final ElementLocator locator)
			throws AludraTestException;

	public boolean isEditable(final ElementLocator locator)
			throws AludraTestException;

	public void select(final ElementLocator locator,
			final OptionLocator optionLocator) throws AludraTestException;

	public void type(final ElementLocator locator, final String value)
			throws AludraTestException;

	public String getText(final ElementLocator locator)
			throws AludraTestException;

	public boolean isChecked(final ElementLocator locator)
			throws AludraTestException;

	public String[] getSelectOptions(final ElementLocator locator)
			throws AludraTestException;

	public String getSelectedValue(final ElementLocator locator)
			throws AludraTestException;

	public boolean hasFocus(final ElementLocator locator)
			throws AludraTestException;

	public String getSelectedLabel(final ElementLocator locator)
			throws AludraTestException;

	public String getValue(final ElementLocator locator)
			throws AludraTestException;

	public String[] getValues(final ElementLocator locator)
			throws AludraTestException;

	public String[] getLabels(final ElementLocator locator)
			throws LocatorNotSupportedException;

	public void selectWindow(final WindowLocator windowLocator)
			throws AludraTestException;

	public void focus(final ElementLocator elementLocator)
			throws AludraTestException;

	public String[] getAllWindowTitles() throws AludraTestException;

	public String getTitle() throws AludraTestException;

	public String getAttributeValue(final ElementLocator elementLocator,
			final String attributeName) throws AludraTestException;

	public void windowMaximize() throws AludraTestException;

	public void windowFocus() throws AludraTestException;

	public Attachment getScreenshotOfThePage() throws AludraTestException;

	public Attachment getScreenshotOfTheWholeScreen()
			throws AludraTestException;

	public Attachment getPageSource() throws AludraTestException;

	public void waitForPageToLoad() throws AludraTestException;

	public void keyPress(final int key) throws AludraTestException;

	public void doubleClick(final ElementLocator locator)
			throws AludraTestException;

	public void close() throws AludraTestException;

	/**
	 * @deprecated This method will be removed and not replaced
	 */
	@Deprecated
	public String getTable(final ElementLocator elementLocator, int row, int col)
			throws AludraTestException;

	/**
	 * @deprecated This method will be replaced with a method which returns the result of a XPath expression
	 */
	@Deprecated
	public Number getXPathCount(String xpath);

	public boolean retryUntilTimeout(final Condition condition)
			throws TechnicalException, LocatorNotSupportedException,
			NumberFormatException;

	public void waitForElement(final ElementLocator locator)
			throws ElementCouldNotBeFoundException,
			LocatorNotSupportedException, TechnicalException;

	public void waitForVisible(final ElementLocator locator)
			throws ElementCouldNotBeFoundException,
			LocatorNotSupportedException, TechnicalException,
			NotVisibleException;

	public void waitForEnabled(final ElementLocator locator)
			throws ElementCouldNotBeFoundException,
			LocatorNotSupportedException, TechnicalException,
			NotVisibleException, NotEditableException;

	public void waitForInForeground(final ElementLocator locator)
			throws LocatorNotSupportedException, TechnicalException,
			NotInForegroundException;
	
	public void waitForElementNotPresent(final ElementLocator locator) 
			throws ElementCouldBeFoundException,
			LocatorNotSupportedException, TechnicalException;
	
	public void waitForElement(final ElementLocator locator, final long timeout)
			throws ElementCouldNotBeFoundException,
			LocatorNotSupportedException, TechnicalException;

	public void waitForVisible(final ElementLocator locator, final long timeout)
			throws ElementCouldNotBeFoundException,
			LocatorNotSupportedException, TechnicalException,
			NotVisibleException;

	public void waitForEnabled(final ElementLocator locator, final long timeout)
			throws ElementCouldNotBeFoundException,
			LocatorNotSupportedException, TechnicalException,
			NotVisibleException, NotEditableException;

	public void waitForInForeground(final ElementLocator locator,
			final long timeout) throws LocatorNotSupportedException,
			TechnicalException, NotInForegroundException;
	
	public void waitForElementNotPresent(final ElementLocator locator,
			final long timeout) throws ElementCouldBeFoundException,
			LocatorNotSupportedException, TechnicalException;
}
